@@ -9,11 +9,11 @@ module Notifier
     def notify(options)
       command = [
         "dcop", "knotify", "default", "notify", "eventname",
-        options[:title], options[:message],
+        options[:title].to_s, options[:message].to_s,
         "", "", "16", "2"
       ]
 
-      Thread.new { system(*command) }
+      Thread.new { system(*command) }.join
     end
   end
 end
