@@ -3,7 +3,7 @@ require "notifier"
 module SpecHelpers
   def unsupport_all_notifiers
     Notifier.notifiers.each do |notifier|
-      notifier.stub :supported? => false unless notifier == Notifier::Placebo
+      allow(notifier).to receive_messages(:supported? => false) unless notifier == Notifier::Placebo
     end
   end
 end
